import time
import requests
from sms_reg_api.exceptions import *


class Sms:
    def __init__(self, api_key):
        self._api_key = api_key
        self._check_auth()

    def _send(self, method, param=None):
        response = requests.get(f'http://api.sms-reg.com/{method}.php?{param}&apikey={self._api_key}').json()
        if response['response'] == 'ERROR':
            raise MethodError(response.get('error_msg', None))
        else:
            return response

    def _check_auth(self):
        if requests.get(f'http://api.sms-reg.com/getBalance.php?&'
                        f'apikey={self._api_key}').json()['response'] == 'ERROR':
            raise BadToken('Wrong api key')

    def balance(self):
        return self._send('getBalance')['balance']

    def set_rate(self, rate):
        return self._send('setRate', param=f'{float(rate)}')

    def get_list(self, extended=None):
        return requests.get(f'http://api.sms-reg.com/getList.php?extended={extended}&'
                            f'apikey={self._api_key}').json()['services']

    def get_num(self, service, country=None):
        if country:
            return self._send('getNum', param=f'country={country}&service={service}')['tzid']
        else:
            return self._send('getNum', param=f'service={service}')['tzid']

    def get_num_repeat(self, tzid):
        return self._send('getNumRepeat', param=f'tzid={tzid}')

    def set_ready(self, tzid):
        return self._send('set_ready', param=f'tzid={tzid}')

    def _get_state(self, tzid):
        return self._send('getState', param=f'tzid={tzid}')

    def get_operations(self, opstate=None, count=None, output=None):
        return self._send('getOperations', param=f'opstate={opstate}&'
                                                 f'count={count}&'
                                                 f'output={output}')

    def wait_number(self, tzid):
        while self._get_state(tzid).get('response', None) == 'TZ_INPOOL':
            time.sleep(3)

        response = self._get_state(tzid)

        if response.get('response', None) == 'TZ_NUM_PREPARE':
            return response['number']
        else:
            return False

    def wait_answer(self, tzid):
        while self._get_state(tzid).get('response', None) == 'TZ_NUM_WAIT':
            time.sleep(3)

        response = self._get_state(tzid)

        if response.get('response', None) == 'TZ_NUM_ANSWER':
            return response['msg']
        else:
            return False

    def set_ok(self, tzid):
        return self._send('setOperationOk', param=f'tzid={tzid}')

    def set_used(self, tzid):
        return self._send('setOperationUsed', param=f'tzid={tzid}')



import string
import unittest
from random import choice, randint

import sms_reg_api
from sms_reg_api.sms_reg import Sms
'''
Api_key изменен, попытка
использовать ключ из тестов
не увенчается успехом.
'''


class SmsTest(unittest.TestCase):
    def test_auth_error(self):
        with self.assertRaises(sms_reg_api.exceptions.BadToken):
            for _ in range(10):
                Sms(''.join([choice(string.ascii_uppercase + string.digits) for _ in range(randint(1, 10000))]))

    def test_auth_normal(self):
            self.assertTrue(Sms('2d08p37k6bkwjpj1pqgwdsbg9nuy2g1y'))

    def test_balance(self):
        self.assertTrue(Sms('2d08p37k6bkwjpj1pqgwdsbg9nuy2g1y').balance())

    def test_get_operations(self):
        self.assertTrue(Sms('2d08p37k6bkwjpj1pqgwdsbg9nuy2g1y').get_operations())


if __name__ == "__main__":
    unittest.main()



import setuptools

with open("README.md", ) as f:
    long_description = f.read()

setuptools.setup(
    name='sms-reg',
    version='0.4',
    description=' Python API for sms-reg.com',
    license="MIT",
    long_description=long_description,
    author='Valentine Bobrovsky',
    author_email='vbabrouski@outlook.com',
    url="http://linkedin.com/in/vbxx3",
    packages=setuptools.find_packages(),  # same as name
    install_requires=["setuptools", "requests"],  # external packages as dependencies
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
